Shardmonster
============

A tool for managing sharding of Mongo using pure Python. Crucially, allows for
multi-version clusters of Mongo. Useful for upgrades.


Docs available at http://shardmonster.readthedocs.org/en/latest/
